develooper Front page | perl.perl5.porters | Postings from January 2011

[perl #81842] [PATCH] Fix typos (spelling errors) in cpan/Object-Accessor/*.

Thread Next
From:
perlbug-followup
Date:
January 7, 2011 01:57
Subject:
[perl #81842] [PATCH] Fix typos (spelling errors) in cpan/Object-Accessor/*.
Message ID:
rt-3.6.HEAD-5425-1294384200-1266.81842-75-0@perl.org
# New Ticket Created by  (Peter J. Acklam) 
# Please include the string:  [perl #81842]
# in the subject line of all future correspondence about this issue. 
# <URL: http://rt.perl.org/rt3/Ticket/Display.html?id=81842 >


---
 cpan/Object-Accessor/lib/Object/Accessor.pm |   12 ++++++------
 cpan/Object-Accessor/t/00_Object-Accessor.t |    2 +-
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/cpan/Object-Accessor/t/00_Object-Accessor.t b/cpan/Object-Accessor/t/00_Object-Accessor.t
index e0f2f13..bc207c2 100644
--- a/cpan/Object-Accessor/t/00_Object-Accessor.t
+++ b/cpan/Object-Accessor/t/00_Object-Accessor.t
@@ -23,7 +23,7 @@ $Object::Accessor::DEBUG = $Object::Accessor::DEBUG = 1 if @ARGV;
     isa_ok( $Object,            $Class );
 }
 
-### check non existant accessor
+### check non existent accessor
 {   my $warning;
     local $SIG{__WARN__} = sub { $warning .= "@_" };
 
diff --git a/cpan/Object-Accessor/lib/Object/Accessor.pm b/cpan/Object-Accessor/lib/Object/Accessor.pm
index 7166200..c943ee0 100644
--- a/cpan/Object-Accessor/lib/Object/Accessor.pm
+++ b/cpan/Object-Accessor/lib/Object/Accessor.pm
@@ -59,7 +59,7 @@ Object::Accessor - interface to create per object accessors
     $obj    = My::Class->new;               # create base object
     $bool   = $obj->mk_accessors('foo');    # create accessors, etc...
 
     ### make all attempted access to non-existant accessors fatal
     ### (defaults to false)
     $Object::Accessor::FATAL = 1;
 
@@ -118,7 +118,7 @@ Any arguments given to C<new> are passed straight to C<mk_accessors>.
 
 If you want to be able to assign to your accessors as if they
 were C<lvalue>s, you should create your object in the 
-C<Object::Acccessor::Lvalue> namespace instead. See the section
+C<Object::Accessor::Lvalue> namespace instead. See the section
 on C<LVALUE ACCESSORS> below.
 
 =cut
@@ -546,7 +546,7 @@ sub ___autoload {
 =head2 $val = $self->___get( METHOD_NAME );
 
 Method to directly access the value of the given accessor in the
-object. It circumvents all calls to allow checks, callbakcs, etc.
+object. It circumvents all calls to allow checks, callbacks, etc.
 
 Use only if you C<Know What You Are Doing>! General usage for 
 this functionality would be in your own custom callbacks.
@@ -564,7 +564,7 @@ sub ___get {
 =head2 $bool = $self->___set( METHOD_NAME => VALUE );
 
 Method to directly set the value of the given accessor in the
-object. It circumvents all calls to allow checks, callbakcs, etc.
+object. It circumvents all calls to allow checks, callbacks, etc.
 
 Use only if you C<Know What You Are Doing>! General usage for 
 this functionality would be in your own custom callbacks.
@@ -674,7 +674,7 @@ C<perl 5.8.x> feature. See perldoc L<perl58delta> for details.
 =item * Allow handlers
 
 Due to the nature of C<lvalue subs>, we never get access to the
-value you are assigning, so we can not check it againt your allow
+value you are assigning, so we can not check it against your allow
 handler. Allow handlers are therefor unsupported under C<lvalue>
 conditions.
 
@@ -772,7 +772,7 @@ See C<perldoc perlsub> for details.
 
 =head2 $Object::Accessor::FATAL
 
-Set this variable to true to make all attempted access to non-existant
+Set this variable to true to make all attempted access to non-existent
 accessors be fatal.
 This defaults to C<false>.
 
@@ -59,7 +59,7 @@ Object::Accessor - interface to create per object accessors
     $bool   = $obj->mk_accessors('foo');    # create accessors, etc...
 
-    ### make all attempted access to non-existant accessors fatal
+    ### make all attempted access to non-existent accessors fatal
     ### (defaults to false)
     $Object::Accessor::FATAL = 1;
-- 
1.7.3.3


Thread Next


nntp.perl.org: Perl Programming lists via nntp and http.
Comments to Ask Bjørn Hansen at ask@perl.org | Group listing | About